@@ -126,8 +126,6 @@ class AWSSource(AbstractSource):
                     "size": instance["InstanceType"],
                     "start_date": instance["LaunchTime"],
                     "state": instance["State"]["Name"],
-                    "subnet": instance["SubnetId"],
-                    "vpc": instance["VpcId"],
                 }
 
                 # Correct the state
@@ -149,6 +147,11 @@ class AWSSource(AbstractSource):
                         for security_group in instance["SecurityGroups"]
                     ]
 
+                # Get the instance network information
+                with suppress(KeyError):
+                    entity_data["vpc"] = instance["VpcId"]
+                    entity_data["subnet"] = instance["SubnetId"]
+
                 # Get the private ips
                 with suppress(KeyError):
                     entity_data["private_ips"] = []
